#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
using namespace std;
typedef long long ll;

const ll mod = 1e9 + 7;

vector<int> cnt_consec_zeros(const vector<bool>& row)
{
	int n = row.size();
	vector<int> res(n);
	int l = 0, r = 1;
	int cnt_zeros;
	while (r < n)
	{
		cnt_zeros = 0;
		while (r < n && row[r] == 0)
		{
			r++;
			cnt_zeros++;
		}
		while (l < r)
		{
			res[l] = cnt_zeros;
			cnt_zeros--;
			l++;
		}
		r++;
	}
	return res;
}

vector<int> suffix_sum(const vector<bool>& row)
{
	int n = row.size();
	vector<int> suffix(n);
	suffix.back() = row.back();
	for (int i = n - 2; i >= 0; i--)
		suffix[i] = suffix[i + 1] + row[i];
	return suffix;
}

vector<pair<int, int>> get_intervals(const vector<bool>& row, int k)
{
	int l = 0;
	int n = row.size();
	vector<pair<int, int>> intervals;
	int s = 0;

	while (l < n && row[l] == 1)
		l++;
	int r = l + 1;
	while (l < n)
	{
		while (r < n && s <= k)
			s += row[r++];
		if (l+1 <= r-s-1)
			intervals.push_back({ l + 1,r - s - 1 });
		l++;
		while (l < n && row[l] == 1)
		{
			s--;
			l++;
		}
	}
	return intervals;
}

void fill_dp(const vector<ll>& prev_dp, vector<ll>& dp, const vector<bool>& row, int power)
{
	auto intervals = get_intervals(row, power);
	vector<pair<int, ll>> to_add; to_add.reserve(2*intervals.size());
	for (auto p: intervals)
	{
		to_add.push_back({ p.first, prev_dp[p.first - 1] });
		to_add.push_back({ p.second+1, -prev_dp[p.first - 1] });
	}
	int j = 0;
	ll sol = 0;
	for (int i = 0; i < dp.size(); i++)
	{
		while (j < to_add.size() && to_add[j].first == i)
		{
			sol += to_add[j].second;
			j++;
		}
		dp[i] = sol;
	}
}

ll solve(const vector<vector<bool>>& mat, int power)
{
	int row_cnt = mat.size();
	int n = mat[0].size();
	vector<ll> dp(n);
	auto prev_dp = dp;
	for (int i = 0; i < n; i++)
		prev_dp[i] = (!mat[row_cnt-1][i]);
	for (int i = row_cnt - 1; i > 0; i--)
	{
		for (int j = 0; j < n; j++)
			if (mat[i][j] == 1)
				prev_dp[j] = 0;
		
		auto dp_rev = dp;
		reverse(dp_rev.begin(), dp_rev.end());

		fill_dp(prev_dp, dp, mat[i], power);
		
		auto prev_dp_rev = prev_dp;
		reverse(prev_dp_rev.begin(), prev_dp_rev.end());
		auto row_rev = mat[i];
		reverse(row_rev.begin(), row_rev.end());
		fill_dp(prev_dp_rev, dp_rev, row_rev, power);
		reverse(dp_rev.begin(), dp_rev.end());
		for (int i = 0; i < n; i++)
			dp[i] += dp_rev[i];

		for (int i = 0; i < n; i++)
			dp[i] += prev_dp[i];
		
		prev_dp = dp;
	}
	ll sol = 0;
	for (int i = 0; i < dp.size(); i++)
	{
		if (mat[0][i] == 0)	
			sol += dp[i];
	}
	return sol;
}

int main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);
	
	int n, m, k; cin >> n >> m >> k;
	vector<vector<bool>> mat(n, vector<bool>(m));
	for (int i = 0; i < n; i++)
	{
		string s; cin >> s;
		for (int j = 0; j < m; j++)
			mat[i][j] = (s[j] == '1');
	}
	cout << solve(mat, k);


	return 0;
}