#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <map>
using namespace std;
typedef long long ll;

class SegmentTree
{
public:
	SegmentTree(vector<int> elements);
	int sum_query(int l, int r);
	void update(int pos, int new_val);
private:
	int element_cnt;
	vector<int> tree;
};

struct point
{
	ll x, y;
	int index;
};

bool operator < (const point& lhs, const point& rhs)
{
	return lhs.x < rhs.x;
}

int find_point_by_x(SegmentTree& tree, int n, map<ll,point>& points_by_x)
{
	int l = -1, r = n;
	while (r - l > 1)
	{
		int mid = (l + r) / 2;
		int cnt_left = tree.sum_query(0, mid);
		int cnt_right = tree.sum_query(mid + 1, n);
		if (cnt_left < cnt_right)
			l = mid;
		else if (cnt_left > cnt_right)
			r = mid;
		if (cnt_left == cnt_right)
		{
			return points_by_x[mid].index;
		}
	}
	return -1;
}

bool check_y(SegmentTree& tree_y, int n, int pos)
{
	int cnt_bellow = tree_y.sum_query(0, pos);
	int cnt_above = tree_y.sum_query(pos + 1, n);
	return cnt_bellow == cnt_above;
}

vector<point> compress_coords(vector<point> points)
{
	int n = points.size();
	sort(points.begin(), points.end());
	int current_x = 0;
	for (int i = 0; i < n; i++)
	{
		if (i > 0 && points[i].x != points[i - 1].x)
			current_x++;
		points[i].x = current_x;
	}
	for (int i = 0; i < n; i++)
		swap(points[i].x, points[i].y);
	sort(points.begin(), points.end());
	current_x = 0;
	for (int i = 0; i < n; i++)
	{
		if (i > 0 && points[i].x != points[i - 1].x)
			current_x++;
		points[i].x = current_x;
	}
	for (int i = 0; i < n; i++)
		swap(points[i].x, points[i].y);
	return points;
}

int main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);

	int n; cin >> n;
	vector<point> points(n);
	for (int i = 0; i < n; i++)
	{
		ll x, y;
		cin >> x >> y;
		points[i] = { x,y,i };
	}
	
	auto compressed_pts = compress_coords(points);
	map<ll, point> points_by_x;
	for (int i = 0; i < n; i++)
	{
		points_by_x[compressed_pts[i].x] = compressed_pts[i];
	}

	sort(compressed_pts.begin(), compressed_pts.end(), [](const point& lhs, const point& rhs) {return lhs.index < rhs.index; });
	auto tree_x = SegmentTree(vector<int>(n));
	auto tree_y = SegmentTree(vector<int>(n));
	for (int i = 0; i < n; i++)
	{
		int x = compressed_pts[i].x;
		int y = compressed_pts[i].y;
		tree_x.update(x, 1);
		tree_y.update(y, 1);
		int ind = find_point_by_x(tree_x, n, points_by_x);
		if (ind != -1 && check_y(tree_y, n, ind))
			cout << ind+1 << "\n";
		else
			cout << "-1\n";
	}
	return 0;
}

SegmentTree::SegmentTree(vector<int> elements)
{
	element_cnt = elements.size();
	tree = vector<int>(2 * element_cnt);
	copy(elements.begin(), elements.end(), tree.begin() + element_cnt);
	for (int i = element_cnt - 1; i > 0; i--)
		tree[i] = tree[2 * i] + tree[2 * i + 1];
}

int SegmentTree::sum_query(int l, int r)
{
	l += element_cnt;
	r += element_cnt;
	int sum = 0;
	while (l < r)
	{
		if (l % 2 == 1)
		{
			sum += tree[l++];
		}
		if (r % 2 == 1)
		{
			sum += tree[--r];
		}
		l /= 2;
		r /= 2;
	}
	return sum;
}

void SegmentTree::update(int pos, int new_val)
{
	pos += element_cnt;
	tree[pos] = new_val;
	for (int i = pos/2; i > 0; i/=2)
		tree[i] = tree[2 * i] + tree[2 * i + 1];
}