#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <map>
#include <queue>
using namespace std;
typedef long long ll;

vector<int> bfs(int node, const vector<vector<int>>& graph)
{
	queue<pair<int,int>> bfs_queue;
	bfs_queue.push({ node,0 });
	vector<int> dists(graph.size(),-1);
	dists[node] = 0;
	while (!bfs_queue.empty())
	{
		int current_node = bfs_queue.front().first;
		int d = bfs_queue.front().second;
		bfs_queue.pop();
		for (int neighbor: graph[current_node])
		{
			if (dists[neighbor] == -1)
			{
				dists[neighbor] = d + 1;
				bfs_queue.push({ neighbor,d + 1 });
			}
		}
	}
	return dists;
}

pair<int,pair<int,int>> bruteforce(const vector<vector<int>>& tree)
{
	int n = tree.size();
	int sol = INT_MAX;
	pair<int, int> best_edge = { -1,-1 };
	int best_src = -1;
	for (int src = 0; src < n; src++)
	{
		for (int i = 0; i < n; i++)
		{
			auto graph = tree;
			if (i != src)
			{
				graph[i].push_back(src);
				graph[src].push_back(i);
				auto dists = bfs(src, graph);
				int max_d = *max_element(dists.begin(), dists.end());
				if (max_d < sol)
				{
					best_edge = { src+1,i+1 };
					best_src = src;
					sol = max_d;
				}
			}
		}
	}
	return { best_src+1,best_edge };
}

int main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);

	int n; cin >> n;
	if (n > 400)
	{
		return 0;
	}
	vector<vector<int>> tree(n, vector<int>(n));
	for (int i = 0; i < n-1; i++)
	{
		int a, b; cin >> a >> b;
		a--; b--;
		tree[a].push_back(b);
		tree[b].push_back(a);
	}
	auto sol = bruteforce(tree);
	cout << sol.second.first << " " << sol.second.second << "\n" << sol.first << "\n";
	return 0;
}